<route lang="json5" type="page">
{
  layout: 'default',
  style: {
    navigationBarTitleText: '设备点检',
  },
}
</route>

<template>
  <view class="bg-base">
    <wd-form ref="form" :model="model" :rules="rules">
      <wd-cell-group custom-class="group" title="设备信息" border>
        <wd-input
          @click.stop="handleSelectEqu"
          label="设备名称"
          label-width="200rpx"
          prop="equId"
          readonly
          required
          suffix-icon="arrow-right"
          clearable
          v-model="model.equId"
          placeholder="请选择设备"
          @clicksuffixicon="handleSelectEqu"
        />
        <!--        <wd-picker
          label="设备名称"
          placeholder="请选设备"
          label-width="200rpx"
          prop="equId"
          v-model="model.equId"
          :columns="equList"
        />-->
      </wd-cell-group>

      <wd-cell-group custom-class="mt-2" title="点检信息" border>
        <wd-picker
          label="点检项"
          placeholder="请选点检项"
          label-width="200rpx"
          prop="equId"
          v-model="model.inspName"
          :columns="equList"
        />

        <wd-input
          label="点检编号"
          placeholder="请生成点检编号"
          label-width="200rpx"
          v-model="model.inspCode"
          prop="inspCode"
        >
          <template #suffix>
            <wd-button size="small" @click.stop="handleInspCode">生成</wd-button>
          </template>
        </wd-input>

        <wd-textarea
          label="点检描述"
          label-width="200rpx"
          type="textarea"
          v-model="model.inspDesc"
          auto-height
          :maxlength="200"
          show-word-limit
          placeholder="请输入点检描述"
          clearable
          prop="inspDesc"
        />
        <wd-cell title="点检图片" title-width="200rpx" prop="fileList">
          <wd-upload
            :file-list="model.fileList"
            :action="VITE_UPLOAD_BASEURL"
            @change="handleFileChange"
          ></wd-upload>
        </wd-cell>

        <wd-calendar
          label="计划日期"
          label-width="200rpx"
          placeholder="请选择日期"
          prop="planTime"
          v-model="model.planTime"
        />
        <wd-datetime-picker
          label="点检时间"
          label-width="200rpx"
          placeholder="请选择时间"
          prop="inspTime"
          v-model="model.inspTime"
        />
      </wd-cell-group>

      <view class="footer">
        <wd-button type="primary" style="margin: 20px" block @click="handleSubmit" >提交</wd-button>
      </view>
    </wd-form>
  </view>
</template>
<script setup lang="ts">
import { reactive, ref } from 'vue'
import { FormRules } from 'wot-design-uni/components/wd-form/types'
import { getEnvBaseUploadUrl } from '@/utils'

const VITE_UPLOAD_BASEURL = `${getEnvBaseUploadUrl()}`

const form = ref()
const model = reactive<{
  equId: string
  inspName: string
  inspCode: string
  inspDesc: string
  planTime: null | number
  inspTime: number | string
  fileList: []
}>({
  equId: '',
  inspName: '',
  inspCode: '',
  inspDesc: '',
  planTime: null,
  inspTime: '',
  fileList: [],
})
const rules: FormRules = {
  equId: [
    {
      required: true,
      message: '请选择设备',
    },
  ],
  inspName: [
    {
      required: true,
      message: '请选择点检项',
    },
  ],
  inspCode: [
    {
      required: true,
      message: '请输入点检编码',
    },
  ],
  inspDesc: [
    {
      required: true,
      message: '请输入点检描述',
    },
  ],
  fileList: [
    {
      required: false,
      message: '',
    },
  ],
}

const equList = ref<any[]>([
  {
    value: '1',
    label: '1#干燥机',
  },
  {
    value: '2',
    label: '1#干燥机',
  },
])

/**
 * 选择设备
 */
function handleSelectEqu() {
  uni.navigateTo({
    url: '/pages/equ/equ-list',
    events: {
      // 为指定事件添加一个监听器，获取被打开页面传送到当前页面的数据
      selectEqu: function (data) {
        console.log(data)
      },
    },
    success: function (res) {
      // 通过eventChannel向被打开页面传送数据
      res.eventChannel.emit('handleSelectEqu', { data: '点检页面选择设备' })
    },
  })
}

/**
 * 生成点检编号
 */
function handleInspCode() {
  console.error('生成点检编码')
}

/**
 * 上传点检图片
 * @param fileList
 */
function handleFileChange({ fileList }) {
  model.fileList = fileList
}

function handleSubmit() {
  form.value
    .validate()
    .then(({ valid, errors }) => {
      console.log(valid)
      console.log(errors)
    })
    .catch((error) => {
      console.log(error, 'error')
    })
}
</script>
<style scoped lang="scss">
.footer {
  background: white;
  padding: 60rpx 42rpx;
}
</style>
